package de.intevation.flys.jfree;

import org.apache.log4j.Logger;

import org.jfree.chart.axis.ValueAxis;
import org.jfree.data.Range;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DoubleBounds implements Bounds {

    protected double lower;
    protected double upper;


    public DoubleBounds(double lower, double upper) {
        this.lower = lower;
        this.upper = upper;
    }


    @Override
    public Number getLower() {
        return Double.valueOf(lower);
    }


    @Override
    public Number getUpper() {
        return Double.valueOf(upper);
    }


    @Override
    public void applyBounds(ValueAxis axis) {
        axis.setRange(new Range(lower, upper));
    }


    @Override
    public Bounds combine(Bounds bounds) {
        if (bounds == null) {
            return this;
        }

        DoubleBounds other = (DoubleBounds) bounds;

        double otherLower = other.getLower().doubleValue();
        double otherUpper = other.getUpper().doubleValue();

        return new DoubleBounds(
            otherLower < lower ? otherLower : lower,
            otherUpper > upper ? otherUpper : upper);
    }


    @Override
    public String toString() {
        return "DoubleBounds=[" + lower + " ; " + upper + "]";
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
